@@ -1,11 +1,13 @@
 #include "demo-common.h"
 #include <glibmm/fileutils.h>
 #include <glibmm/miscutils.h> //For Glib::build_filename().
+#include <iostream>
 
 #ifdef GLIBMM_WIN32
 
 #undef DEMOCODEDIR
 
+// TODO: Apply scorched earth tactics on code below.
 static char *
 get_democodedir(void)
 {
@@ -13,7 +15,7 @@ get_democodedir(void)
 
   if (result == NULL)
     {
-      result = g_win32_get_package_installation_directory (NULL, NULL);
+      result = g_win32_get_package_installation_directory_of_module(0);
       if (result == NULL)
 	result = "unknown-location";
 
@@ -51,6 +53,7 @@ std::string demo_find_file(const std::string& base)
     if(!Glib::file_test(filename, Glib::FILE_TEST_EXISTS))
     {
       Glib::ustring msg = "Cannot find demo data file " + base;  
+
       throw Glib::FileError(Glib::FileError::NO_SUCH_ENTITY, msg);
       return Glib::ustring();
     }
