@@ -1,5 +1,5 @@
 
-#include <glib.h>
+#include <glibmm.h>
 
 // Disable the 'const' function attribute of the get_type() functions.
 // GCC would optimize them out because we don't use the return value.
@@ -79,7 +79,7 @@ namespace Gdk {
 void wrap_init()
 {
   // Register Error domains:
-  Glib::Error::register_domain(gdk_pixbuf_error_quark(), &Gdk::PixbufError::throw_func);
+  Glib::Error::register_domain(gdk_pixbuf_error_quark(), &::Gdk::PixbufError::throw_func);
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(gdk_cursor_get_type(), &Gdk::Cursor_Class::wrap_new);
