@@ -1,5 +1,5 @@
 
-#include <glib.h>
+#include <glibmm.h>
 
 // Disable the 'const' function attribute of the get_type() functions.
 // GCC would optimize them out because we don't use the return value.
@@ -24,7 +24,6 @@
 #include "appchooserbutton.h"
 #include "appchooserdialog.h"
 #include "appchooserwidget.h"
-#include "application.h"
 #include "arrow.h"
 #include "aspectframe.h"
 #include "assistant.h"
@@ -78,12 +77,15 @@
 #include "fontbutton.h"
 #include "fontchooser.h"
 #include "fontchooserdialog.h"
+#include "fontchooserwidget.h"
 #ifndef GTKMM_DISABLE_DEPRECATED
 #include "fontselection.h"
 #endif // *_DISABLE_DEPRECATED
 #include "frame.h"
 #include "grid.h"
+#ifndef GTKMM_DISABLE_DEPRECATED
 #include "handlebox.h"
+#endif // *_DISABLE_DEPRECATED
 #ifndef GTKMM_DISABLE_DEPRECATED
 #include "hvbox.h"
 #endif // *_DISABLE_DEPRECATED
@@ -187,9 +189,13 @@
 #include "stylecontext.h"
 #include "styleprovider.h"
 #include "switch.h"
+#ifndef GTKMM_DISABLE_DEPRECATED
 #include "table.h"
+#endif // *_DISABLE_DEPRECATED
 #include "targetlist.h"
+#ifndef GTKMM_DISABLE_DEPRECATED
 #include "tearoffmenuitem.h"
+#endif // *_DISABLE_DEPRECATED
 #include "textattributes.h"
 #include "textbuffer.h"
 #include "textchildanchor.h"
@@ -243,7 +249,6 @@ GType gtk_alignment_get_type(void);
 GType gtk_app_chooser_button_get_type(void);
 GType gtk_app_chooser_dialog_get_type(void);
 GType gtk_app_chooser_widget_get_type(void);
-GType gtk_application_get_type(void);
 GType gtk_arrow_get_type(void);
 GType gtk_aspect_frame_get_type(void);
 GType gtk_assistant_get_type(void);
@@ -289,8 +294,8 @@ GType gtk_file_chooser_widget_get_type(void);
 GType gtk_file_filter_get_type(void);
 GType gtk_fixed_get_type(void);
 GType gtk_font_button_get_type(void);
-GType gtk_font_chooser_get_type(void);
 GType gtk_font_chooser_dialog_get_type(void);
+GType gtk_font_chooser_widget_get_type(void);
 #ifndef GTKMM_DISABLE_DEPRECATED
 GType gtk_font_selection_get_type(void);
 #endif // *_DISABLE_DEPRECATED
@@ -317,7 +322,9 @@ GType gtk_hscrollbar_get_type(void);
 #ifndef GTKMM_DISABLE_DEPRECATED
 GType gtk_hseparator_get_type(void);
 #endif // *_DISABLE_DEPRECATED
+#ifndef GTKMM_DISABLE_DEPRECATED
 GType gtk_handle_box_get_type(void);
+#endif // *_DISABLE_DEPRECATED
 GType gtk_icon_factory_get_type(void);
 GType gtk_icon_theme_get_type(void);
 GType gtk_icon_view_get_type(void);
@@ -389,8 +396,12 @@ GType gtk_status_icon_get_type(void);
 GType gtk_statusbar_get_type(void);
 GType gtk_style_context_get_type(void);
 GType gtk_switch_get_type(void);
+#ifndef GTKMM_DISABLE_DEPRECATED
 GType gtk_table_get_type(void);
+#endif // *_DISABLE_DEPRECATED
+#ifndef GTKMM_DISABLE_DEPRECATED
 GType gtk_tearoff_menu_item_get_type(void);
+#endif // *_DISABLE_DEPRECATED
 GType gtk_text_buffer_get_type(void);
 GType gtk_text_child_anchor_get_type(void);
 GType gtk_text_mark_get_type(void);
@@ -460,7 +471,6 @@ namespace Gtk {  class Alignment_Class { public: static Glib::ObjectBase* wrap_n
 namespace Gtk {  class AppChooserButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class AppChooserDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class AppChooserWidget_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gtk {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Arrow_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class AspectFrame_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Assistant_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -506,8 +516,8 @@ namespace Gtk {  class FileChooserWidget_Class { public: static Glib::ObjectBase
 namespace Gtk {  class FileFilter_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Fixed_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class FontButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gtk {  class FontChooser_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class FontChooserDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gtk {  class FontChooserWidget_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #ifndef GTKMM_DISABLE_DEPRECATED
 namespace Gtk {  class FontSelection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif // *_DISABLE_DEPRECATED
@@ -534,7 +544,9 @@ namespace Gtk {  class HScrollbar_Class { public: static Glib::ObjectBase* wrap_
 #ifndef GTKMM_DISABLE_DEPRECATED
 namespace Gtk {  class HSeparator_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif // *_DISABLE_DEPRECATED
+#ifndef GTKMM_DISABLE_DEPRECATED
 namespace Gtk {  class HandleBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#endif // *_DISABLE_DEPRECATED
 namespace Gtk {  class IconFactory_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class IconTheme_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class IconView_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -606,8 +618,12 @@ namespace Gtk {  class StatusIcon_Class { public: static Glib::ObjectBase* wrap_
 namespace Gtk {  class Statusbar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class StyleContext_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Switch_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#ifndef GTKMM_DISABLE_DEPRECATED
 namespace Gtk {  class Table_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#endif // *_DISABLE_DEPRECATED
+#ifndef GTKMM_DISABLE_DEPRECATED
 namespace Gtk {  class TearoffMenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#endif // *_DISABLE_DEPRECATED
 namespace Gtk {  class TextBuffer_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class TextChildAnchor_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class TextMark_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -677,7 +693,6 @@ void wrap_init()
   Glib::wrap_register(gtk_app_chooser_button_get_type(), &Gtk::AppChooserButton_Class::wrap_new);
   Glib::wrap_register(gtk_app_chooser_dialog_get_type(), &Gtk::AppChooserDialog_Class::wrap_new);
   Glib::wrap_register(gtk_app_chooser_widget_get_type(), &Gtk::AppChooserWidget_Class::wrap_new);
-  Glib::wrap_register(gtk_application_get_type(), &Gtk::Application_Class::wrap_new);
   Glib::wrap_register(gtk_arrow_get_type(), &Gtk::Arrow_Class::wrap_new);
   Glib::wrap_register(gtk_aspect_frame_get_type(), &Gtk::AspectFrame_Class::wrap_new);
   Glib::wrap_register(gtk_assistant_get_type(), &Gtk::Assistant_Class::wrap_new);
@@ -723,8 +738,8 @@ void wrap_init()
   Glib::wrap_register(gtk_file_filter_get_type(), &Gtk::FileFilter_Class::wrap_new);
   Glib::wrap_register(gtk_fixed_get_type(), &Gtk::Fixed_Class::wrap_new);
   Glib::wrap_register(gtk_font_button_get_type(), &Gtk::FontButton_Class::wrap_new);
-  Glib::wrap_register(gtk_font_chooser_get_type(), &Gtk::FontChooser_Class::wrap_new);
   Glib::wrap_register(gtk_font_chooser_dialog_get_type(), &Gtk::FontChooserDialog_Class::wrap_new);
+  Glib::wrap_register(gtk_font_chooser_widget_get_type(), &Gtk::FontChooserWidget_Class::wrap_new);
 #ifndef GTKMM_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_font_selection_get_type(), &Gtk::FontSelection_Class::wrap_new);
 #endif // *_DISABLE_DEPRECATED
@@ -751,7 +766,9 @@ void wrap_init()
 #ifndef GTKMM_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_hseparator_get_type(), &Gtk::HSeparator_Class::wrap_new);
 #endif // *_DISABLE_DEPRECATED
+#ifndef GTKMM_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_handle_box_get_type(), &Gtk::HandleBox_Class::wrap_new);
+#endif // *_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_icon_factory_get_type(), &Gtk::IconFactory_Class::wrap_new);
   Glib::wrap_register(gtk_icon_theme_get_type(), &Gtk::IconTheme_Class::wrap_new);
   Glib::wrap_register(gtk_icon_view_get_type(), &Gtk::IconView_Class::wrap_new);
@@ -823,8 +840,12 @@ void wrap_init()
   Glib::wrap_register(gtk_statusbar_get_type(), &Gtk::Statusbar_Class::wrap_new);
   Glib::wrap_register(gtk_style_context_get_type(), &Gtk::StyleContext_Class::wrap_new);
   Glib::wrap_register(gtk_switch_get_type(), &Gtk::Switch_Class::wrap_new);
+#ifndef GTKMM_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_table_get_type(), &Gtk::Table_Class::wrap_new);
+#endif // *_DISABLE_DEPRECATED
+#ifndef GTKMM_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_tearoff_menu_item_get_type(), &Gtk::TearoffMenuItem_Class::wrap_new);
+#endif // *_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_text_buffer_get_type(), &Gtk::TextBuffer_Class::wrap_new);
   Glib::wrap_register(gtk_text_child_anchor_get_type(), &Gtk::TextChildAnchor_Class::wrap_new);
   Glib::wrap_register(gtk_text_mark_get_type(), &Gtk::TextMark_Class::wrap_new);
@@ -882,7 +903,6 @@ void wrap_init()
   Gtk::AppChooserButton::get_type();
   Gtk::AppChooserDialog::get_type();
   Gtk::AppChooserWidget::get_type();
-  Gtk::Application::get_type();
   Gtk::Arrow::get_type();
   Gtk::AspectFrame::get_type();
   Gtk::Assistant::get_type();
@@ -928,8 +948,8 @@ void wrap_init()
   Gtk::FileFilter::get_type();
   Gtk::Fixed::get_type();
   Gtk::FontButton::get_type();
-  Gtk::FontChooser::get_type();
   Gtk::FontChooserDialog::get_type();
+  Gtk::FontChooserWidget::get_type();
 #ifndef GTKMM_DISABLE_DEPRECATED
   Gtk::FontSelection::get_type();
 #endif // *_DISABLE_DEPRECATED
@@ -956,7 +976,9 @@ void wrap_init()
 #ifndef GTKMM_DISABLE_DEPRECATED
   Gtk::HSeparator::get_type();
 #endif // *_DISABLE_DEPRECATED
+#ifndef GTKMM_DISABLE_DEPRECATED
   Gtk::HandleBox::get_type();
+#endif // *_DISABLE_DEPRECATED
   Gtk::IconFactory::get_type();
   Gtk::IconTheme::get_type();
   Gtk::IconView::get_type();
@@ -1028,8 +1050,12 @@ void wrap_init()
   Gtk::Statusbar::get_type();
   Gtk::StyleContext::get_type();
   Gtk::Switch::get_type();
+#ifndef GTKMM_DISABLE_DEPRECATED
   Gtk::Table::get_type();
+#endif // *_DISABLE_DEPRECATED
+#ifndef GTKMM_DISABLE_DEPRECATED
   Gtk::TearoffMenuItem::get_type();
+#endif // *_DISABLE_DEPRECATED
   Gtk::TextBuffer::get_type();
   Gtk::TextChildAnchor::get_type();
   Gtk::TextMark::get_type();
